<?php
/**
 * @package com_tinydoc for Joomla! 4.x
 * @version $Id: controller.php 2024-05-02 $
 * @author Andreas Thul
 * @copyright (c) 2009-2024 Andreas Thul
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
**/

// 2014-09-16 athul/changed DS to DIRECTORY_SEPARATOR
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.controller');
jimport('joomla.filesystem.file');
jimport('joomla.utilities.date');

// 2014-09-16 athul/changed JController to JControllerLegacy
class TinyDocController extends JControllerLegacy {

	function __construct() {

		parent::__construct();
		$this->registerTask('add', 'edit');
		$this->registerTask('unpublish', 'publish');
		$this->registerTask('gallery_unpublish', 'gallery_publish');
		$this->registerTask('unskip', 'skip');
	}

	// 2012-08-17 athul/improved error handling
	// 2014-09-16 athul/Only variables should be assigned by reference
	// 2014-09-16 athul/changed JDate::toFormat() to JDate::Format()
	function save() {

		// 2024-04-22 athul/replaced $option = JRequest::getCmd('option');
		$jinput = JFactory::getApplication()->input;
		$option = $jinput->get('option');

		// 2024-05-02 athul/added task
		$this->setRedirect('index.php?option=' . $option . '&task=listDocuments');

		// 2024-04-22 athul/replaced $post = JRequest::get('post');
		$post = $jinput->post->getArray();

		// 2024-04-22 athul/replaced $upload = JRequest::get('files');
		$upload = $jinput->files->get('document_upload');

		// 2024-04-29 athul/$upload might be null if file is reagrded unsafe
		// empty file chooser leads to array with keys
		if ((!is_null($upload)) && (!$upload['error'])) {

			$row = JTable::getInstance('Document', 'Table');

			if (!$row->bind($post) || !$row->store()) {
				// 2024-04-29 athul/replaced JError::raiseWarning
				// return JError::raiseWarning(500, $row->getError());
				return $this->setMessage($row->getError(), 'error');
			}

			// 2012-08-08 athul/set initial value of ordering to id
			if ($row->ordering == null) { $row->ordering = $row->id; }

			$error = 0;
			// 2024-04-23 athul/changed from $upload['document_upload']['name']
			if (strlen($upload['name']) > 0) {

				// 2024-04-23 athul/changed from $upload['document_upload']['tmp_name']
				if (!JFile::upload($upload['tmp_name'], TinyDocHelper::getDocumentFile($row->id))) {

					// 2024-04-29 athul/replaced $this->setError
					// $this->setError( JText::_('Error uploading the file') );
					$this->setMessage( JText::_('Error uploading the file'), 'error');
					$row->delete();

					$error = 1;
				}
				else {

					// 2024-04-23 athul/changed from $upload['name']
					$row->name = $upload['name'];
					// 2024-04-23 athul(changed from $upload['document_upload']['size']
					$row->size = $upload['size'];
					// 2024-04-23 athul/changed from $upload['document_upload']['type']
					$row->type_id = TinyDocHelper::getTypeID($upload['type']);
					// $row->type = $upload['document_upload']['type'];

					$now = new JDate();
					$row->date = $now->Format('Y-m-d');

					if (!$row->store()) {
						// 2024-04-29 athul/replaced
						// return JError::raiseWarning(500, $row->getError());
						return $this->setMessage($row->getError(), 'error');
					}
				}
			}
			if (! $error) { $this->setMessage(JText::_('MESSAGE_DOCUMENT_SAVED')); }
		}
		else {
			$error = 1;
			$this->setMessage(JText::_('MESSAGE_DOCUMENT_NOT_UPLOADED'), 'error');
		}
	}

	function saveFolder() {

		// 2024-04-22 athul/replaced $option = JRequest::getCmd('option');
		$jinput = JFactory::getApplication()->input;
		$option = $jinput->get('option');

		$this->setRedirect('index.php?option=' . $option . '&task=listFolders');

		// 2024-04-22 athul/replaced $post = JRequest::get('post');
		$post = $jinput->post->getArray();

		// 2024-04-29 athul/Only variables should be assigned by reference
		// $row =& JTable::getInstance('Folder', 'Table');
		$row = JTable::getInstance('Folder', 'Table');

		if (!$row->bind($post)) {
			// 2024-04-29 athul/replaced JError::raiseWarning
			// return JError::raiseWarning(500, $row->getError());
			return $this->setMessage($row->getError(), 'error');
		}

		if (!$row->store()) {
			// 2024-04-29 athul/replaced JError::raiseWarning
			// return JError::raiseWarning(500, $row->getError());
			return $this->setMessage($row->getError(), 'error');
		}

		$this->setMessage(JText::_('MESSAGE_FOLDER_SAVED'));
	}

	// 2013-06-03 athul/Only variables should be assigned by reference
	function editDocument() {

		// 2024-04-22 athul/replaced $cid = JRequest::getVar('cid', array(), 'request', 'array');
		$jinput = JFactory::getApplication()->input;
		$cid = $jinput->get('cid', array(), 'request', 'array');

		$row = JTable::getInstance('Document', 'Table');

		if (isset($cid[0])) {
			$row->load($cid[0]);
		}

		// 2024-05-02 athul/added
		$jinput->set('hidemainmenu', true);

		// 2024-04-22 athul/replaced $option = JRequest::getCmd('option');
		$option = $jinput->get('option');

		HTML_TinyDoc::edit($option, $row);
	}

	// 2013-06-03 athul/Only variables should be assigned by reference
	function editFolder() {

		// 2024-04-22 athul/replaced $cid = JRequest::getVar('cid', array(), 'request', 'array');
		$jinput = JFactory::getApplication()->input;
		$cid = $jinput->get('cid', array(), 'request', 'array');

		$row = JTable::getInstance('Folder', 'Table');

		if (isset($cid[0])) {
			$row->load($cid[0]);
		}

		// 2024-05-02 athul/added
		$jinput->set('hidemainmenu', true);

		// 2024-04-22 athul/replaced $option = JRequest::getCmd('option');
		$option = $jinput->get('option');

		HTML_TinyDoc::editFolder($option, $row);
	}

	function removeDocument() {

		// 2024-04-22 athul/replaced $option = JRequest::getCmd('option');
		$jinput = JFactory::getApplication()->input;
		$option = $jinput->get('option');

		$this->setRedirect('index.php?option=' . $option);

		// 2024-04-29 athul/Only variables should be assigned by reference
		// $db	=& JFactory::getDBO();
		$db	= JFactory::getDBO();
		// 2024-04-22 athul/replaced $cid = JRequest::getVar('cid', array(), 'request', 'array');
		$cid = $jinput->get('cid', array(), 'request', 'array');

		$count = count($cid);

		if ($count) {

			foreach ($cid as $id) {

				$db->setQuery('DELETE FROM #__tinydoc_document WHERE id = ' . $id );
				// 2024-04-22 athul/replaced $db->query()
				// 2024-04-29 athul/replaced JError::raiseWarning
				// if (!$db->execute()) { JError::raiseWarning( 500, $db->getError() ); }
				if (!$db->execute()) { $this->setMessage($db->getError(), 'error'); }

				$file = TinyDocHelper::getDocumentFile($id);
				if (file_exists($file)) { unlink($file); }
				}

			$this->setMessage(JText::_('MESSAGE_DOCUMENT_DELETED'));
		}
	}

	function removeFolder() {

		// 2024-04-22 athul/replaced $option = JRequest::getCmd('option');
		$jinput = JFactory::getApplication()->input;
		$option = $jinput->get('option');

		$this->setRedirect('index.php?option=' . $option . '&task=listFolders');

		// 2024-04-29 athul/Only variables should be assigned by reference
		// $db	=& JFactory::getDBO();
		$db	= JFactory::getDBO();

		// 2024-04-22 athul/replaced $cid = JRequest::getVar('cid', array(), 'request', 'array');
		$cid = $jinput->get('cid', array(), 'request', 'array');

		$count = count($cid);

		if ($count) {

			foreach ($cid as $id) {

				$db->setQuery("SELECT count(*) FROM #__tinydoc_document WHERE folder_id = $id");
				// 2024-04-22 athul/replaced $db->query()
				if (!$db->execute()) { JError::raiseWarning( 500, $db->getError() ); }
				$total = $db->loadResult();

				if ($total) {
					// 2024-04-29 athul/replaced JError::raiseWarning
					// JError::raiseWarning( 500, "folder #$id not empty");
					$this->setMessage("folder #$id not empty", 'error');
				}
				else {
					$db->setQuery('DELETE FROM #__tinydoc_folder WHERE id = ' . $id );
					// 2024-04-22 athul/replaced $db->query()
					if (!$db->execute()) { JError::raiseWarning( 500, $db->getError() ); }

					$this->setMessage(JText::_('MESSAGE_FOLDER_DELETED'));
				}
			}
		}
	}

	function publish() {

		// 2024-04-22 athul/replaced $option = JRequest::getCmd('option');
		$jinput = JFactory::getApplication()->input;
		$option = $jinput->get('option');

		$this->setRedirect('index.php?option=' . $option);

		// 2024-04-22 athul/replaced $cid = JRequest::getVar('cid', array(), 'request', 'array');
		$cid = $jinput->get('cid', array(), 'request', 'array');

		if ($this->getTask() == 'publish') { $publish = 1; }
		else { $publish = 0; }

		// 2024-04-29 athul/Only variables should be assigned by reference
		// $table =& JTable::getInstance('Document', 'Table');
		$table = JTable::getInstance('Document', 'Table');

		$table->publish($cid, $publish);

		$this->setMessage(JText::_('MESSAGE_PUBLISHED_CHANGED'));
	}

	// 2012-08-08 athul/added code for manual ordering
	// 2013-06-03 athul/Only variables should be assigned by reference
	// 2015-05-15 athul/fix for variable $filter not being initialized before being used
	function listDocuments() {

		$mainframe = JFactory::getApplication();
		// 2024-04-22 athul/replaced $option = JRequest::getCmd('option');
		$jinput = JFactory::getApplication()->input;
		$option = $jinput->get('option');

		$limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
		$limitstart = $mainframe->getUserStateFromRequest($option.'.limitstart', 'limitstart', 0, 'int');
		$search = $mainframe->getUserStateFromRequest($option.'search', 'search', '', 'string');

		$filter_state = $mainframe->getUserStateFromRequest($option.'filter_state', 'filter_state', '', 'word');
		$filter_folder_id = $mainframe->getUserStateFromRequest($option.'filter_folder_id',	'filter_folder_id', 0, 'int');
		$filter_type_id = $mainframe->getUserStateFromRequest($option.'filter_type_id',	'filter_type_id', 0, 'int');

		$filter = '';
		$filter_order		= $mainframe->getUserStateFromRequest($option.'filter_order',		'filter_order',		'id',	'cmd' );
		$filter_order_Dir	= $mainframe->getUserStateFromRequest($option.'filter_order_Dir',	'filter_order_Dir',	'',			'word' );

		$lists['search'] = $search;

		$db	= JFactory::getDBO();

		if (strlen($search) > 0) { $search = " WHERE description LIKE '%$search%' "; }

		if ($filter_folder_id) {

			if (strlen($search) > 0) { $search .= " AND folder_id = $filter_folder_id "; }
			else { $search = " WHERE folder_id = $filter_folder_id "; }
		}

		if ($filter_type_id) {

			if (strlen($search) > 0) { $search .= " AND type_id = $filter_type_id "; }
			else { $search = " WHERE type_id = $filter_type_id "; }
		}

		if ($filter_state) {
			if ($filter_state == 'P') {
				$filter .= 'published = 1';
			}
			elseif ($filter_state == 'U') {
				$filter .= 'published = 0';
			}

			if (strlen($search) > 0) { $search .= " AND $filter "; }
			else { $search = " WHERE $filter "; }
		}

		// sanitize $filter_order
		if (!in_array($filter_order, array('name', 'description', 'date', 'size', 'ordering', 'id'))) {
			$filter_order = 'name';
		}

		if (!in_array(strtoupper($filter_order_Dir), array('ASC', 'DESC'))) {
			$filter_order_Dir = '';
		}
		$orderby	= ' ORDER BY ' . $filter_order . ' ' . $filter_order_Dir . ', ordering';

		$db->setQuery("SELECT count(*) FROM #__tinydoc_document $search");
		// 2024-04-22 athul/replaced $db->query()
		// 2024-04-29 athul/replaced JError::raiseWarning
		// if (!$db->execute()) { JError::raiseWarning( 500, $db->getError() ); }
		if (!$db->execute()) { $this->setMessage($db->getError(), 'error'); }
		$total = $db->loadResult();

		$db->setQuery("SELECT * FROM #__tinydoc_document $search $orderby", $limitstart, $limit);
		// 2024-04-22 athul/replaced $db->query()
		// 2024-04-29 athul/replaced JError::raiseWarning
		// if (!$db->execute()) { JError::raiseWarning( 500, $db->getError() ); }
		if (!$db->execute()) { $this->setMessage( 500, $db->getError(), 'error'); }
		$rows = $db->loadObjectList();

		jimport('joomla.html.pagination');
		$pageNav = new JPagination($total, $limitstart, $limit);

		$javascript 	= 'onchange="document.adminForm.submit();"';
		$lists['folder_id'] = TinyDocHelper::selectFolder('filter_folder_id', $option, intval($filter_folder_id), $javascript);
		$lists['type_id'] = TinyDocHelper::selectType('filter_type_id', $option, intval($filter_type_id), $javascript);
		$lists['state']	= JHTML::_('grid.state',  $filter_state );

		// table ordering
		$lists['order_Dir']	= $filter_order_Dir;
		$lists['order']		= $filter_order;

		HTML_TinyDoc::listDocuments($option, $rows, $pageNav, $lists);
	}

	// 2013-06-03 athul/Only variables should be assigned by reference
	function listFolders() {

		$mainframe = JFactory::getApplication();
		// 2024-04-22 athul/replaced $option = JRequest::getCmd('option');
		$jinput = JFactory::getApplication()->input;
		$option = $jinput->get('option');

		$limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
		$limitstart = $mainframe->getUserStateFromRequest($option.'.limitstart', 'limitstart', 0, 'int');
		$search = $mainframe->getUserStateFromRequest( $option.'search', 'search', '', 'string');

		$db	= JFactory::getDBO();

		$db->setQuery("SELECT count(*) FROM #__tinydoc_folder");
		// 2024-04-22 athul/replaced $db->query()
		// 2024-04-29 athul/replaced JError::raiseWarning
		// if (!$db->execute()) { JError::raiseWarning( 500, $db->getError() ); }
		if (!$db->execute()) { $this->setMessage($db->getError(), 'error'); }
		$total = $db->loadResult();

		// 2024-05-02 athul/added missing $limitstart, $limit
		$db->setQuery("SELECT * FROM #__tinydoc_folder ORDER BY name ASC", $limitstart, $limit);
		// 2024-04-22 athul/replaced $db->query()
		// 2024-04-29 athul/replaced JError::raiseWarning
		// if (!$db->execute()) { JError::raiseWarning( 500, $db->getError() ); }
		if (!$db->execute()) { $this->setMessage($db->getError(), 'error'); }
		$rows = $db->loadObjectList();

		jimport('joomla.html.pagination');
		$pageNav = new JPagination($total, $limitstart, $limit);

		HTML_TinyDoc::listFolders($option, $rows, $pageNav);
	}

	// 2013-06-03 athul/Only variables should be assigned by reference
	function listTypes() {

		$mainframe = JFactory::getApplication();

		// 2024-04-22 athul/replaced $option = JRequest::getCmd('option');
		$jinput = JFactory::getApplication()->input;
		$option = $jinput->get('option');

		$limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
		$limitstart = $mainframe->getUserStateFromRequest($option.'.limitstart', 'limitstart', 0, 'int');
		$search = $mainframe->getUserStateFromRequest( $option.'search', 'search', '', 'string');

		$db	= JFactory::getDBO();

		$db->setQuery("SELECT count(*) FROM #__tinydoc_type");
		// 2024-04-22 athul/replaced $db->query()
		// 2024-04-29 athul/replaced JError::raiseWarning
		// if (!$db->execute()) { JError::raiseWarning( 500, $db->getError() ); }
		if (!$db->execute()) { $this->setMessage($db->getError(), 'error'); }
		$total = $db->loadResult();

		$db->setQuery("SELECT * FROM #__tinydoc_type ORDER BY type ASC");
		// 2024-04-22 athul/replaced $db->query()
		// 2024-04-29 athul/replaced JError::raiseWarning
		// if (!$db->execute()) { JError::raiseWarning( 500, $db->getError() ); }
		if (!$db->execute()) { $this->setMessage($db->getError(), 'error'); }
		$rows = $db->loadObjectList();

		jimport('joomla.html.pagination');
		$pageNav = new JPagination($total, $limitstart, $limit);

		HTML_TinyDoc::listTypes($option, $rows, $pageNav);
	}

	function showAbout() {

		// 2013-06-03 athul/Only variables should be assigned by reference
		// 2024-04-22 athul/replaced $option = JRequest::getCmd('option');
		$jinput = JFactory::getApplication()->input;
		$option = $jinput->get('option');

		// 2024-04-22 athul/replaced "JApplicationHelper::parseXMLInstallFile" with "JInstaller::parseXMLInstallFile"
		if (! $xmldata = JInstaller::parseXMLInstallFile(JPATH_COMPONENT . DIRECTORY_SEPARATOR . 'tinydoc.xml')) {

			$xmldata['creationdate'] = 'unknown';
			$xmldata['version'] = 'unknown';
			$xmldata['description'] = 'none';
			$xmldata['name'] = 'none';
			$xmldata['license'] = 'none';
		}

		HTML_TinyDoc::about($xmldata);
	}

	function updateTypes() {

		// 2024-04-22 athul/replaced $option = JRequest::getCmd('option');
		$jinput = JFactory::getApplication()->input;
		$option = $jinput->get('option');

		$this->setRedirect('index.php?option=' . $option . '&task=listTypes');

		// 2024-04-29 athul/Only variables should be assigned by reference
		// $db	=& JFactory::getDBO();
		$db	= JFactory::getDBO();

		// 2024-04-22 athul/replaced $post = JRequest::get('post');
		$post = $jinput->post->getArray();

		foreach ($post as $key => $value) {

			if (preg_match("/^__type_/", $key)) {

				$key = preg_replace("/^__type_/", "", $key);

				$db->setQuery("UPDATE #__tinydoc_type SET icon='$value' WHERE id = '$key';");
				// 2024-04-22 athul/replaced $db->query()
				// 2024-04-29 athul/replaced JError::raiseWarning
				// if (!$db->execute()) { JError::raiseWarning( 500, $db->getError() ); }
				if (!$db->execute()) { $this->setMessage($db->getError(), 'error'); }
			}

		}
	}

	function saveOrder() {

		$option = JRequest::getCmd('option');
		$this->setRedirect('index.php?option=' . $option . '&task=listDocuments');

		// Initialize variables
		// 2024-04-29 athul/Only variables should be assigned by reference
		// $db			=& JFactory::getDBO();
		$db			= JFactory::getDBO();
		$cid		= JRequest::getVar('cid', array(), 'post', 'array' );
		$order		= JRequest::getVar('order', array(), 'post', 'array' );
		// $row		=& JTable::getInstance('document', 'Table');
		$row		= JTable::getInstance('document', 'Table');
		$total		= count($cid);
		$conditions	= array();

		if (empty( $cid )) {
			// 2024-04-29 athul/replaced JError::raiseWarning
			// return JError::raiseWarning( 500, JText::_('No items selected') );
			return $this->setMessage(JText::_('No items selected'), 'warning');
		}

		// update ordering values
		for ($i = 0; $i < $total; $i++)
		{
			$row->load((int) $cid[$i]);
			if ($row->ordering != $order[$i])
			{
				$row->ordering = $order[$i];
				if (!$row->store()) {
					// 2024-04-29 athul/replaced JError::raiseWarning
					// return JError::raiseError( 500, $db->getErrorMsg() );
					return $this->setMessage($db->getErrorMsg(), 'error');
				}
			}
		}

		// Clear the component's cache
		// 2024-04-29 athul/Only variables should be assigned by reference
		// $cache =& JFactory::getCache($option);
		$cache = JFactory::getCache($option);
		$cache->clean();

		$this->setMessage(JText::_('New ordering saved'));
	}

	function orderup() {

		$option = JRequest::getCmd('option');
		$this->setRedirect('index.php?option=' . $option . '&task=listDocuments');

		$cid = JRequest::getVar('cid', array(0), '', 'array');
		// 2024-04-29 athul/Only variables should be assigned by reference
		// $db =& JFactory::getDBO();
		$db = JFactory::getDBO();

		// document to be moved down
		$id = $cid[0];
		// 2024-04-29 athul/Only variables should be assigned by reference
		// $row=& JTable::getInstance('Document', 'Table');
		$row= JTable::getInstance('Document', 'Table');
		$row->load($id);

		// document to be swapped with
		$query = "SELECT id FROM #__tinydoc_document WHERE ordering < " . $row->ordering . " ORDER BY ordering DESC LIMIT 1";
		$db->setQuery($query);
		$tmp = $db->loadObject();

		// 2024-04-29 athul/Only variables should be assigned by reference
		// $row2=& JTable::getInstance('Document', 'Table');
		$row2= JTable::getInstance('Document', 'Table');
		$row2->load($tmp->id);

		$row_ordering = $row->ordering;
		$row2_ordering = $row2->ordering;

		$row->ordering = $row2_ordering;
		$row2->ordering = $row_ordering;

		if (!$row->store()) {
			// 2024-04-29 athul/replaced JError::raiseWarning
			// return JError::raiseWarning(500, $row->getError());
			return $this->setMessage($row->getError(), 'error');
		}
		if (!$row2->store()) {
			// 2024-04-29 athul/replaced JError::raiseWarning
			// return JError::raiseWarning(500, $row->getError());
			return $this->setMessage($row->getError(), 'error');
		}

		// Clear the component's cache
		// 2024-04-29 athul/Only variables should be assigned by reference
		// $cache =& JFactory::getCache($option);
		$cache = JFactory::getCache($option);
		$cache->clean();

		$this->setMessage(JText::_('New ordering saved'));

	}

  function orderdown() {

		$option = JRequest::getCmd('option');
		$this->setRedirect('index.php?option=' . $option . '&task=listDocuments');

		$cid = JRequest::getVar('cid', array(0), '', 'array');
		// 2024-04-29 athul/Only variables should be assigned by reference
		// $db =& JFactory::getDBO();
		$db = JFactory::getDBO();

		// document to be moved down
		$id = $cid[0];
		// 2024-04-29 athul/Only variables should be assigned by reference
		// $row=& JTable::getInstance('Document', 'Table');
		$row= JTable::getInstance('Document', 'Table');
		$row->load($id);

		// document to be swapped with
		$query = "SELECT id FROM #__tinydoc_document WHERE ordering > " . $row->ordering . " ORDER BY ordering ASC LIMIT 1";
		$db->setQuery($query);
		$tmp = $db->loadObject();

		// 2024-04-29 athul/Only variables should be assigned by reference
		// $row2=& JTable::getInstance('Document', 'Table');
		$row2= JTable::getInstance('Document', 'Table');
		$row2->load($tmp->id);

		$row_ordering = $row->ordering;
		$row2_ordering = $row2->ordering;

		$row->ordering = $row2_ordering;
		$row2->ordering = $row_ordering;

		if (!$row->store()) {
			// 2024-04-29 athul/replaced JError::raiseWarning
			// return JError::raiseWarning(500, $row->getError());
			return $this->setMessage($row->getError(), 'error');
		}
		if (!$row2->store()) {
			// 2024-04-29 athul/replaced JError::raiseWarning
			// return JError::raiseWarning(500, $row->getError());
			return $this->setMessage($row->getError(), 'error');
		}

		// Clear the component's cache
		// 2024-04-29 athul/Only variables should be assigned by reference
		// $cache =& JFactory::getCache($option);
		$cache = JFactory::getCache($option);
		$cache->clean();

		$this->setMessage(JText::_('New ordering saved'));
  }

	// 2024-05-02 athul/added
	function cancelDocument() {

		$jinput = JFactory::getApplication()->input;
		$option = $jinput->get('option');

		$this->setRedirect('index.php?option=' . $option . '&task=listDocuments');
	}

	// 2024-05-02 athul/added
	function cancelFolder() {

		$jinput = JFactory::getApplication()->input;
		$option = $jinput->get('option');

		$this->setRedirect('index.php?option=' . $option . '&task=listFolders');
	}

}

?>
