<?php
/**
 * @package com_tinydoc for Joomla! 4.x
 * @version $Id: admin.tinydoc.html.php 2024-05-02
 * @author Andreas Thul
 * @copyright (c) 2009-2024 Andreas Thul
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
**/

// 2013-06-03 athul/changed all methods to static
// 2014-09-16 athul/changed DS to DIRECTORY_SEPARATOR
defined('_JEXEC') or die('Restricted access');

class HTML_TinyDoc {

	// 2013-06-03 athul/Only variables should be assigned by reference
	// 2014-09-16 athul/added id="adminForm"
	// 2015-05-15 athul/switched to drag & drop sorting
	// 2015-05-16 athul/fix for displaying sort order
	static function listDocuments($option, &$rows, &$pageNav, $lists) {

		HTML_TinyDoc::setListDocumentsToolbar();
		$config = JComponentHelper::getParams('com_tinydoc');
		$ordering = ($lists['order'] == 'ordering');
		$saveOrderingUrl = 'index.php?option=com_tinydoc&task=saveOrder&tmpl=component';

		HTML_TinyDoc::setSubmenu('documents');
		echo JHtml::_('searchtools.form', '#adminForm');
		echo JHtml::_('sortablelist.sortable', 'documentList', 'adminForm', $lists['order_Dir'], $saveOrderingUrl);

		?>
		<form action="index.php" method="post" name="adminForm" id="adminForm">

		<div class="form-inline form-inline-header">
			<div class="control-group">
<!--  2024-04-26 athul/removed
				<div class="control-label">
					<?php echo JText::_('LABEL_FILTER_DESCRIPTION'); ?>:
				</div>
 -->				<div class="controls">
				 	<!-- 2024-04-26 athul/addec class "btn btn-primary" -->
					<input type="text" name="search" id="search" value="<?php echo $lists['search'];?>" class="form-control text_area" onchange="document.adminForm.submit();" />
					<!-- 2024-04-26 athul/addec class "btn btn-primary" -->
					<button class="btn btn-primary" onclick="this.form.submit();"><?php echo JText::_('BUTTON_SEARCH'); ?></button>
					<button class="btn btn-secondary" onclick="document.getElementById('search').value='';this.form.getElementById('filter_category_id').value='0';this.form.getElementById('filter_state').value='';this.form.submit();"><?php echo JText::_('BUTTON_RESET'); ?></button>
				</div>
			</div>
			<div class="control-group">
<!-- 2024-04-26 athul/removed
				<div class="control-label">
				</div>
 -->				<div class="controls">
					<?php
						echo $lists['folder_id'];
						echo $lists['type_id'];
						echo $lists['state'];
					?>
				</div>
			</div>
		</div>

			<table class="adminlist table table-striped" id="documentList">
				<thead>
					<tr>
						<th width="1%" class="nowrap center hidden-phone">
							<!-- 2024-05-02 athul/changed text to icon -->
							<?php echo JHTML::_('grid.sort', '<span class="ms-1 icon-sort"></span>', 'ordering', $lists['order_Dir'], $lists['order'] ); ?>
						</th>
						<th><?php echo JHtml::_('grid.checkall'); ?></th>
						<th nowrap="nowrap" class="title"></th>
						<th nowrap="nowrap" class="title">
							<?php echo JHTML::_('grid.sort',  JText::_('HEAD_NAME'), 'name', $lists['order_Dir'], $lists['order'] ); ?>
						</th>
						<th nowrap="nowrap" class="title"><?php echo JText::_('HEAD_FOLDER'); ?></th>
						<th nowrap="nowrap" class="title">
							<?php echo JHTML::_('grid.sort',  JText::_('HEAD_DESCRIPTION'), 'description', $lists['order_Dir'], $lists['order'] ); ?>
						</th>
						<th nowrap="nowrap" class="title">
							<?php echo JHTML::_('grid.sort',  JText::_('HEAD_DATE'), 'date', $lists['order_Dir'], $lists['order'] ); ?>
						</th>
						<th nowrap="nowrap" class="title">
							<?php echo JHTML::_('grid.sort',  JText::_('HEAD_SIZE'), 'size', $lists['order_Dir'], $lists['order'] ); ?>
						</th>
						<th nowrap="nowrap" class="title"><?php echo JText::_('HEAD_TYPE'); ?></th>
						<th nowrap="nowrap" class="title"><?php echo JText::_('HEAD_PUBLISHED'); ?></th>
						<th nowrap="nowrap" class="title">
							<?php echo JHTML::_('grid.sort','ID', 'id', $lists['order_Dir'], $lists['order'] ); ?>
						</th>
					</tr>
				</thead>
				<tbody class="ui-sortable">
					<?php

					$folder = TinyDocHelper::getFolderArray();
					$type = TinyDocHelper::getTypeArray();
					$icon = TinyDocHelper::getIconArray();

					$k = 0;
					for ($i=0, $n=count( $rows ); $i < $n; $i++) {
						$row = &$rows[$i];

						// 2024-04-22 athul/replaced JHTML::_('grid.published', $row, $i );
						$published = JHtml::_('jgrid.published', $row->published, $i);
 						$checked = JHTML::_('grid.id', $i, $row->id );
 						$url = JRoute::_("/index.php?option=com_tinydoc&view=document&document=" . $row->id . "&format=raw");

						$link = 'index.php?option=' . $option . '&task=editDocument&cid[]='. $row->id;

						?>
						<tr class="<?php echo "row$k"; ?>" sortable-group-id="<?php echo $row->folder_id; ?>">

							<td class="order nowrap center hidden-phone">
								<span class="sortable-handler<?php echo $iconClass ?>">
									<i class="icon-menu"></i>
								</span>
								<input type="text" style="display:none" name="order[]" size="5" value="<?php echo $row->ordering; ?>" class="width-20 text-area-order " />
							</td>

							<!-- check -->
							<td>
								<?php echo $checked; ?>
							</td>

							<!-- icon -->
							<td>
								<a href="<?php echo $url; ?>"><img src="<?php echo JURI::root(); ?>components/com_tinydoc/assets/<?php echo $icon[$row->type_id]; ?>" border="0" /></a>
							</td>

							<!-- name -->
							<td>
								<a href="<?php echo $link; ?>" title="edit document">
								<?php echo $row->name; ?>
								</a>
							</td>

							<!-- folder -->
							<td>
								<?php echo $folder[$row->folder_id]; ?>
							</td>

							<!-- description -->
							<td>
								<?php echo TinyDocHelper::cutText($row->description, $config->get('backend_length_description', 80)); ?>
							</td>

							<!-- date -->
							<td>
								<?php echo JHTML::date($row->date, $config->get('backend_date_format', 'Y-m-d')); ?>
							</td>

							<!-- size -->
							<td>
								<?php
								if ($config->get('backend_convert_size', 1)) {
									echo TinyDocHelper::getSizeAsText($row->size);
								}
								else {
									echo $row->size;
								}
								?>
							</td>

							<!-- type -->
							<td>
								<?php echo $type[$row->type_id]; ?>
							</td>

							<!-- Published -->
							<td align="center">
								<?php echo $published; ?>
							</td>

							<!-- Id -->
							<td>
								<?php echo $row->id; ?>
							</td>
						<?php

						$k = 1 - $k;
					}

					?>
				</tbody>
			<tfoot>
				<td colspan="12"><?php echo $pageNav->getListFooter(); ?></td>
			</tfoot>

			</table>

			<input type="hidden" name="option" value="<?php echo $option; ?>" />
			<input type="hidden" name="task" value="" />
			<input type="hidden" name="boxchecked" value="0" />
			<input type="hidden" name="filter_order" value="<?php echo $lists['order']; ?>" />
			<input type="hidden" name="filter_order_Dir" value="<?php echo $lists['order_Dir']; ?>" />

		</form>
		<?php
	}

	// 2013-06-03 athul/Only variables should be assigned by reference
	// 2014-09-16 athul/added id="adminForm"
	static function listFolders($option, &$rows, &$pageNav) {

		HTML_TinyDoc::setListFoldersToolbar();
		$config = JComponentHelper::getParams('com_tinydoc');

		HTML_TinyDoc::setSubmenu('folders');

		?>
		<form action="index.php" method="post" name="adminForm" id="adminForm">

			<table class="adminlist table table-striped">
				<thead>
					<tr>
						<th width="20"><input type="checkbox" name="toggle" value=""  onclick="checkAll(<?php echo count( $rows ); ?>);" /></th>
						<th nowrap="nowrap" class="title"><?php echo JText::_('HEAD_FOLDER'); ?></th>
						<th nowrap="nowrap" class="title"><?php echo JText::_('HEAD_PARENT'); ?></th>
						<th nowrap="nowrap" class="title">ID</th>
					</tr>
				</thead>
				<tbody>
					<?php

					$folder = TinyDocHelper::getFolderArray();

					$k = 0;
					for ($i=0, $n=count( $rows ); $i < $n; $i++) {
						$row = &$rows[$i];

						$checked = JHTML::_('grid.id', $i, $row->id );
						$link = 'index.php?option=' . $option . '&task=editFolder&cid[]='. $row->id;

						?>
						<tr class="<?php echo "row$k"; ?>">

							<!-- checkbox -->
							<td align="center">
								<?php echo $checked; ?>
							</td>

							<!-- name -->
							<td>
								<a href="<?php echo $link; ?>" title="edit folder">
									<?php echo $row->name ?>
								</a>
							</td>

							<!-- parent -->
							<td>
								<?php echo $folder[$row->parent]; ?>
							</td>

							<!-- ID -->
							<td>
								<?php echo $row->id; ?>
							</td>

						<?php

						$k = 1 - $k;
					}

					?>
				</tbody>
			<tfoot>
				<td colspan="9"><?php echo $pageNav->getListFooter(); ?></td>
			</tfoot>
			</table>

			<input type="hidden" name="option" value="<?php echo $option; ?>" />
			<!-- 2024-05-02 athul/added value -->
			<input type="hidden" name="task" value="listFolders" />
			<input type="hidden" name="boxchecked" value="0" />
		</form>
		<?php
	}

	// 2013-06-03 athul/Only variables should be assigned by reference
	// 2014-09-16 athul/added id="adminForm"
	static function listTypes($option, &$rows, &$pageNav) {

		HTML_TinyDoc::setListTypesToolbar();
		$config = JComponentHelper::getParams('com_tinydoc');

		HTML_TinyDoc::setSubmenu('types');

		?>
		<form action="index.php" method="post" name="adminForm" id="adminForm">

			<table class="adminlist table table-striped">
				<thead>
					<tr>
						<th width="20"><input type="checkbox" name="toggle" value=""  onclick="checkAll(<?php echo count( $rows ); ?>);" /></th>
						<th nowrap="nowrap" class="title"><?php echo JText::_('HEAD_TYPE'); ?></th>
						<th nowrap="nowrap" class="title"><?php echo JText::_('HEAD_ICON'); ?></th>
						<th nowrap="nowrap" class="title">ID</th>
					</tr>
				</thead>
				<tbody>
					<?php

					$icons = TinyDocHelper::getIconList();

					$k = 0;
					for ($i=0, $n=count( $rows ); $i < $n; $i++) {
						$row = &$rows[$i];

						$checked = JHTML::_('grid.id', $i, $row->id );
						$link = 'index.php?option=' . $option . '&task=editFolder&cid[]='. $row->id;

						?>
						<tr class="<?php echo "row$k"; ?>">

							<!-- checkbox -->
							<td align="center">
								<?php echo $checked; ?>
							</td>

							<!-- type -->
							<td>
								<?php echo $row->type ?>
							</td>

							<!-- parent -->
							<td>
								<?php echo TinyDocHelper::getIconRadio($icons, $row->id, $row->icon) ?>
							</td>

							<!-- ID -->
							<td>
								<?php echo $row->id; ?>
							</td>

						<?php

						$k = 1 - $k;
					}

					?>
				</tbody>
			<tfoot>
				<td colspan="9"><?php echo $pageNav->getListFooter(); ?></td>
			</tfoot>
			</table>

			<input type="hidden" name="option" value="<?php echo $option; ?>" />
			<input type="hidden" name="task" value="updateTypes" />
			<input type="hidden" name="boxchecked" value="0" />
		</form>
		<?php
	}

	// 2012-08-17 athul/added HTML_TinyDoc::setSubmenu('')
	// 2014-09-16 athul/added id="adminForm"
	// 2017-01-04 athul/pre-select current filtered folder for new documents
	static function edit($option, &$row) {

		HTML_TinyDoc::setDocumentToolbar($row->id);
		// 2024-04-22 athul/removed JHTML::_('behavior.calendar');

		HTML_TinyDoc::setSubmenu('');

		// get current folder filter
		if ($row->folder_id) {
			$folder_id = $row->folder_id;
		}
		else {
			$folder_id = JFactory::getApplication()->getUserStateFromRequest($option.'filter_folder_id',	'filter_folder_id', 0, 'int');
		}
		?>

		<form action="index.php?option=<?php echo $option; ?>" method="post" name="adminForm" id="adminForm" enctype="multipart/form-data">

		<div class="form-horizontal">
			<div class="row-fluid form-horizontal-desktop">

				<div class="control-group">
					<div class="control-label">
						<label for="document_upload"><?php echo JText::_('LABEL_DOCUMENT'); ?></label>
					</div>
					<div class="controls">
						<!-- 2024-04-26 athul/added class "btn btn-success" -->
						<input type="file" size="80" id="document_upload" name="document_upload" class="btn btn-success" />
					</div>
				</div>

				<div class="control-group">
					<div class="control-label">
						<label for="image"><?php echo JText::_('LABEL_FOLDER'); ?></label>
					</div>
					<div class="controls">
						<?php echo TinyDocHelper::selectFolder('folder_id', $option, $folder_id); ?>
					</div>
				</div>

				<div class="control-group">
					<div class="control-label">
						<label for="description"><?php echo JText::_('LABEL_DESCRIPTION'); ?></label>
					</div>
					<div class="controls">
						<!-- 2024-04-26 athul/added class "form-control" -->
						<input class="inputbox form-control" type="text" name="description" id="description" size="80" value="<?php echo $row->description; ?>" />
					</div>
				</div>

				<div class="control-group">
					<div class="control-label">
						<label for="published"><?php echo JText::_('LABEL_PUBLISHED'); ?></label>
					</div>
					<div class="controls">
						<fieldset class="radio inputbox">
						<?php echo JHTML::_('select.booleanlist',  'published', '', $row->published ); ?>
						</fieldset>
					</div>
				</div>

			</div>
		</div>

		<input type="hidden" name="option" value="<?php echo $option; ?>" />
		<input type="hidden" name="task" value="" />
		<input type="hidden" name="id" value="<?php echo $row->id ?>" />
		</form>
		<?php
	}

	// 2012-08-17 athul/added HTML_TinyDoc::setSubmenu('')
	// 2014-09-16 athul/added name="adminForm"
	static function editFolder($option, &$row) {

		HTML_TinyDoc::setFolderToolbar($row->id);
		HTML_TinyDoc::setSubmenu('');

		?>

		<form action="index.php" method="post" name="adminForm" id="adminForm">

		<div class="form-horizontal">
			<div class="row-fluid form-horizontal-desktop">

				<div class="control-group">
					<div class="control-label">
						<label for="name"><?php echo JText::_('LABEL_NAME'); ?></label>
					</div>
					<div class="controls">
						<!-- 2024-04-26 athul/added class "form-control" -->
						<input class="inputbox form-control" type="text" name="name" id="name" size="80" value="<?php echo $row->name; ?>" />
					</div>
				</div>

				<div class="control-group">
					<div class="control-label">
						<label for="parent"><?php echo JText::_('LABEL_PARENT'); ?></label>
					</div>
					<div class="controls">
						<!-- 2024-04-26 athul/added class "form-control" -->
						<!-- 2024-05-02 athul/changed class to "form-select" -->
						<?php echo JHTML::_('select.genericlist', TinyDocHelper::getFolderList(), 'parent', 'class="inputbox form-select"', 'id', 'name', $row->parent); ?>
					</div>
				</div>

			</div>
		</div>

		<input type="hidden" name="option" value="<?php echo $option; ?>" />
		<input type="hidden" name="task" value="listFolders" />
		<input type="hidden" name="id" value="<?php echo $row->id ?>" />
		</form>
		<?php
	}

	static function about($xmldata) {

		HTML_TinyDoc::setAboutToolbar();
		// 2024-04-22 athul/removed JHTML::_('behavior.calendar');

		HTML_TinyDoc::setSubmenu('about');

	?>

	<div class="form-horizontal">
		<fieldset class="adminform">
			<legend><?php echo JText::_('LEGEND_ABOUT') . ' ' . $xmldata['name']; ?></legend>
			<!-- 2024-05-02 athul/changed class to "table" -->
				<table class="table" cellspacing="1">
					<tr>
						<td class="key" valign="top"><?php echo JText::_('LABEL_DESCRIPTION'); ?></td>
						<td><?php echo JText::_($xmldata['description']); ?></a></td>
					</tr>
					<tr>
						<td class="key"><?php echo JText::_('LABEL_VERSION'); ?></td>
						<td><?php echo $xmldata['version']; ?></td>
					</tr>

					<tr>
						<td class="key"><?php echo JText::_('LABEL_DATE'); ?></td>
						<td><?php echo $xmldata['creationDate']; ?></td>
					</tr>

					<tr>
						<td class="key"><?php echo JText::_('LABEL_COPYRIGHT'); ?></td>
						<td>&copy; by Andreas Thul.</td>
					</tr>

					<!-- 2024-05-02 athul/included link in table -->
					<tr>
						<td class="key"><?php echo JText::_('LABEL_WEBSITE'); ?></td>
						<td><a href="https://blog.thul.org/technik/downloads/joomla-component-tinydoc/">tinyDoc website</a></td>
					</tr>

				</table>
			</fieldset>
		</div>

	<?php
	}

	static function setDocumentToolbar($id) {

		if ($id) { $newEdit = JText::_('TITLE_EDIT_DOCUMENT'); }
		else { $newEdit = JText::_('TITLE_NEW_DOCUMENT'); }

		JToolBarHelper::title($newEdit, 'generic.png');
		JToolBarHelper::save();
		JToolBarHelper::cancel('cancelDocument');
	}

	static function setFolderToolbar($id) {

		if ($id) { $newEdit = JText::_('TITLE_EDIT_FOLDER'); }
		else { $newEdit = JText::_('TITLE_NEW_FOLDER'); }

		JToolBarHelper::title($newEdit, 'generic.png');
		JToolBarHelper::save('saveFolder');
		JToolBarHelper::cancel('cancelFolder');
	}

	static function setAboutToolbar() {

		JToolBarHelper::title(JText::_('TITLE_ABOUT') . ' tinyDoc', 'generic.png');

		JToolBarHelper::preferences('com_tinydoc', '500');
	}

	static function setListDocumentsToolbar() {

		JToolBarHelper::title(JText::_('TITLE_LIST_DOCUMENTS'), 'generic.png');

		JToolBarHelper::addNew('editDocument');
		JToolBarHelper::deleteList(JText::_('WARNING_REMOVE_DOCUMENT'), 'removeDocument');
		JToolBarHelper::preferences('com_tinydoc', '500');
	}

	static function setListFoldersToolbar() {

		JToolBarHelper::title(JText::_('TITLE_LIST_FOLDERS'), 'generic.png');

		JToolBarHelper::addNew('editFolder');
		JToolBarHelper::deleteList(JText::_('WARNING_REMOVE_FOLDER'), 'removeFolder');
		JToolBarHelper::preferences('com_tinydoc', '500');
	}

	static function setListTypesToolbar() {

		JToolBarHelper::title(JText::_('TITLE_LIST_TYPES'), 'generic.png');

		JToolBarHelper::preferences('com_tinydoc', '500');
	}

	// 2024-04-22 athul/replaced JSubMenuHelper::addEntry
	static function setSubmenu($vName) {

		JHtmlSidebar::addEntry(
			JText::_('SUBMENU_DOCUMENTS'),
			'index.php?option=com_tinydoc&task=listDocuments',
			$vName == 'documents'
		);

		JHtmlSidebar::addEntry(
			JText::_('SUBMENU_FOLDERS'),
			'index.php?option=com_tinydoc&task=listFolders',
			$vName == 'folders'
		);

		JHtmlSidebar::addEntry(
			JText::_('SUBMENU_TYPES'),
			'index.php?option=com_tinydoc&task=listTypes',
			$vName == 'types'
		);

		JHtmlSidebar::addEntry(
			JText::_('SUBMENU_ABOUT'),
			'index.php?option=com_tinydoc&task=showAbout',
			$vName == 'about'
		);
	}

}

?>
