<?php
/**
 * @package com_tinydoc for Joomla! 4.x
 * @version $Id: install_uninstall_update_script.php 2024-04-29 $
 * @author Andreas Thul
 * @copyright (c) 2009-2024 Andreas Thul
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
**/

// 2014-09-16: changed DS to DIRECTORY_SEPARATOR

defined('_JEXEC') or die('Restricted access');

jimport('joomla.filesystem.folder');

class com_tinydocInstallerScript {
	/**
	 * method to install the component
	 *
	 * @return void
	 */
	function install($parent) {

		// $parent is the class calling this method
		// $parent->getParent()->setRedirectURL('index.php?option=com_tinydoc');

		$folder = JPath::clean(JPATH_SITE . DIRECTORY_SEPARATOR . 'tinydoc_documents');

		if (!is_dir($folder)) { mkdir($folder); }

		if (!is_dir($folder)) { echo JText::_('MESSAGE_CREATE_FOLDER') . " '$folder'"; }
		else { echo JText::_('MESSAGE_FOLDER_CREATED'); }
	}

	/**
	 * method to uninstall the component
	 *
	 * @return void
	 */
	function uninstall($parent) {
		// $parent is the class calling this method

		$folder = JPath::clean(JPATH_SITE . DIRECTORY_SEPARATOR . 'tinydoc_documents');

		$handler = opendir($folder);

		while ($file = readdir($handler)) {

			if (! preg_match("/^\.+$/", $file)) {
				unlink("$folder/$file");
		    }
		}

		closedir($handler);

		rmdir($folder);

		if (!is_dir($folder)) { echo JText::_('MESSAGE_FOLDER_DELETED'); }
		else { echo JText::_('MESSAGE_DELETE_FOLDER') . " '$folder'"; }
	}

	/**
	 * method to update the component
	 *
	 * @return void
	 */
	function update($parent) {
		// $parent is the class calling this method
	}

	// straight from http://docs.joomla.org/Managing_Component_Updates_with_Joomla!1.6_-_Part_3
	function getParam( $name ) {
		$db = JFactory::getDbo();
		$db->setQuery("SELECT manifest_cache FROM #__extensions WHERE type='component' AND element='com_tinydoc'");
		$manifest = json_decode( $db->loadResult(), true );
		return $manifest[ $name ];
	}

	/**
	 * method to run before an install/update/uninstall method
	 *
	 * @return void
	 */
	function preflight($type, $parent) {
		// $parent is the class calling this method
		// $type is the type of change (install, update or discover_install)

		$db = JFactory::getDbo();

		// get current release
		$db->setQuery("SELECT extension_id FROM #__extensions WHERE type='component' AND element='com_tinydoc';");
		$extensionID = $db->loadResult();

		if ($extensionID) {

			$currentRelease = $this->getParam('version');

			// repair missing schema for component version 0.2.1 and below
			if (version_compare($currentRelease, '0.2.1', 'le')) {

				echo '<p>' . JText::_('MESSAGE_SCHEMA_FIXED') . '</p>';

				$db->setQuery("SELECT extension_id FROM #__extensions WHERE type='component' AND element='com_tinydoc'");
				$extensionID = $db->loadResult();

				$db->setQuery("INSERT INTO #__schemas (extension_id, version_id) VALUES ('$extensionID', '$currentRelease');");
				// 2024-04-22 athul/replaced $db->query()
				// $db->query();
				$db->execute();
			}
		}

	}

	/**
	 * method to run after an install/update/uninstall method
	 *
	 * @return void
	 */
	function postflight($type, $parent) {
		// $parent is the class calling this method
		// $type is the type of change (install, update or discover_install)
	}
}
